from setuptools import setup

setup(name="oms_probability",
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['oms_probability'],
      author='Hung Om',
      author_email='hung.workspace@gmail.com',
      zip_safe=False)
